@@ -21,7 +21,7 @@ from python_kemptech_api.exceptions import (
     ValidationError,
     SubVsCannotCreateSubVs,
     BackupFailed,
-)
+    DownloadUserCertFailed)
 from python_kemptech_api.capabilities import CAPABILITIES, DEFAULT
 from .utils import (
     validate_port,
@@ -29,7 +29,7 @@ from .utils import (
     validate_protocol,
     UseTlsAdapter,
     get_sub_vs_list_from_data,
-)
+    get_api_bool_string)
 
 
 requests.packages.urllib3.disable_warnings()
@@ -54,7 +54,7 @@ class HttpClient(object):
 
     def _do_request(self, http_method, rest_command,
                     parameters=None,
-                    file=None, headers=None):
+                    file=None, headers=None, cert=None):
         """Perform a HTTP request.
 
         :param http_method: GET or POST.
@@ -76,12 +76,15 @@ class HttpClient(object):
                                                          params=parameters,
                                                          verify=False,
                                                          data=payload,
-                                                         headers=headers)
+                                                         headers=headers,
+                                                         cert=cert)
             else:
                 response = self._tls_session.request(http_method, cmd_url,
                                                      params=parameters,
-                                                     timeout=5, verify=False,
-                                                     headers=headers)
+                                                     timeout=utils.TIMEOUT,
+                                                     verify=False,
+                                                     headers=headers,
+                                                     cert=cert)
             if 400 < response.status_code < 500:
                 raise KempTechApiException(msg=response.text)
             else:
@@ -118,7 +121,9 @@ class HttpClient(object):
         return self._do_request('POST', rest_command, parameters=parameters,
                                 file=file, headers=headers)
 
-# ---- Models ---
+    def _get_curl_command_list(self, command):
+        return ['curl', '-s', '-k', '--connect-timeout', str(utils.TIMEOUT),
+                '{}/{}'.format(self.endpoint, command)]
 
 
 def send_response(response):
@@ -132,13 +137,14 @@ def send_response(response):
 class LoadMaster(HttpClient):
     """LoadMaster API object."""
 
-    def __init__(self, ip, username, password, port=443,
+    def __init__(self, ip, username, password, port=443, cert=None,
                  tls_version=utils.DEFAULT_TLS_VERSION):
         self.ip_address = ip
         self.username = username
         self.password = password
         self.port = port
         self.version = None
+        self.cert = cert
         super(LoadMaster, self).__init__(tls_version)
 
     def __repr__(self):
@@ -146,12 +152,18 @@ class LoadMaster(HttpClient):
 
     @property
     def endpoint(self):
-        return "https://{user}:{pw}@{ip}:{port}/access".format(
-            user=self.username,
-            pw=self.password,
-            ip=self.ip_address,
-            port=self.port
-        )
+        if self.cert:
+            return "https://{ip}:{port}/access".format(
+                ip=self.ip_address,
+                port=self.port
+            )
+        else:
+            return "https://{user}:{pw}@{ip}:{port}/access".format(
+                user=self.username,
+                pw=self.password,
+                ip=self.ip_address,
+                port=self.port
+            )
 
     @property
     def access_info(self):
@@ -432,9 +444,8 @@ class LoadMaster(HttpClient):
         file_name = "backups/{}.backup".format(self.ip_address)
 
         with open(file_name, 'wb') as file:
-            curl = ['curl', '-k', '--connect-timeout', '5',
-                    '{}/backup'.format(self.endpoint)]
-            subprocess.call(curl, stdout=file)
+            cmd = self._get_curl_command_list('backup')
+            subprocess.call(cmd, stdout=file)
             file.seek(0, 2)
             if file.tell() == 0:
                 raise BackupFailed(self.ip_address)
@@ -470,6 +481,46 @@ class LoadMaster(HttpClient):
             interface["cidr"] = address_cidr_split[1]
         return interface
 
+    def add_local_user(self, user, password, radius=False):
+        params = {
+            'user': user,
+            'password': password,
+            'radius': get_api_bool_string(radius),
+        }
+        response = self._get('/useraddlocal', params)
+        return send_response(response)
+
+    def delete_local_user(self, user):
+        params = {'user': user}
+        response = self._get('/userdellocal', params)
+        return send_response(response)
+
+    def set_user_perms(self, user, perms=None):
+        perms = [] if perms is None else perms
+        params = {
+            'user': user,
+            'perms': ",".join([perm for perm in perms]),
+        }
+        response = self._get('/usersetperms', params)
+        return send_response(response)
+
+    def new_user_cert(self, user):
+        params = {'user': user}
+        response = self._get('/usernewcert', params)
+        return send_response(response)
+
+    def download_user_cert(self, user):
+        file_name = "{}.cert".format(user)
+
+        with open(file_name, 'wb') as file:
+            cmd = self._get_curl_command_list('userdownloadcert?user={}'
+                                              .format(user))
+            subprocess.call(cmd, stdout=file)
+            file.seek(0, 2)
+            if file.tell() == 0:
+                raise DownloadUserCertFailed(self.ip_address)
+        return file_name
+
 
 class KempBaseObjectModel(object):
     # blacklist attributes that shouldn't be pushed to the loadmaster.
