@@ -18,6 +18,7 @@ PropertyMock = mock.PropertyMock
 from requests import exceptions
 
 import python_kemptech_api.client as client
+from python_kemptech_api import utils
 
 LoadMaster = client.LoadMaster
 
@@ -148,6 +149,12 @@ class Test_LoadMaster:
             res = lm.build_virtual_service(service, "not none")
         assert_is_instance(res, client.VirtualService)
 
+    def test__get_curl_command_list(self):
+        lm = client.LoadMaster('ip', 'username', 'password')
+        expected = ['curl', '-s', '-k', '--connect-timeout', str(utils.TIMEOUT),
+                    'https://username:password@ip:443/access/test']
+        actual = lm._get_curl_command_list("test")
+        assert_equal(expected, actual)
 
 class Test_KempBaseObjectModel:
 
